#
# spec file for package cclive
#
# Copyright (c) 2019 Packman Team <packman@links2linux.de>
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


Name:           cclive
Version:        0.9.3
Release:        7.75
Summary:        Command Line Video Extraction Utility
License:        AGPL-3.0-or-later AND GPL-3.0-or-later
Group:          Productivity/Networking/Other
URL:            http://cclive.sourceforge.net/
Source:         https://sourceforge.net/projects/cclive/files/0.9/cclive-%{version}.tar.xz
# PATCH-FIX-UPSTREAM iostream.patch avvissu@yandex.ru -- Fix build error on openSUSE > 13.2
Patch0:         cclive-0.9.3_iostream.patch
# PATCH-FIX-UPSTREAM gcc5.patch tsuna@lrde.epita.fr -- Fix build with gcc5 (by updating boost.m4 to upstream)
# https://github.com/tsuna/boost.m4
Patch1:         cclive-0.9.3_gcc5.patch
# PATCH-FIX-UPSTREAM subdir.patch avvissu@yandex.ru -- Add option 'subdir-objects'
Patch2:         cclive-0.9.3_subdir.patch
# PATCH-FIX-UPSTREAM cclive-0.9.3_boost1.67.patch aloisio@gmx.com -- fixes build with Boost 1.67
Patch4:         cclive-0.9.3_boost1.67.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libquvi-devel >= 0.2.0
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.24
BuildRequires:  pkgconfig(glibmm-2.4) >= 2.24
BuildRequires:  pkgconfig(libcurl) >= 7.18.0
BuildRequires:  pkgconfig(libpcre) >= 8.02
BuildRequires:  pkgconfig(libpcrecpp) >= 8.02

%description
cclive is a command line video extraction utility similar to clive but focuses
on low requirements. Its features are few and essential.

cclive is intended for users who prefer lightweight and "snappy" programs. It
was written in C and depends on libcurl. cclive sports much of the same
features but some compromises were made along the way to keep the
prerequisites low.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch4 -p1

%build
autoreconf -fiv
%configure

make %{?_smp_mflags} V=1

%install
%make_install

%files
%license COPYING
%doc ChangeLog NEWS README
%{_bindir}/ccl
%{_bindir}/cclive
%{_mandir}/man1/cclive.1%{?ext_man}

%changelog
* Fri May  3 2019 aloisio@gmx.com
- Dropped cclive.buildtime.patch (no longer necessary)
- Added cclive-0.9.3_boost1.67.patch to fix Factory build
  (courtesy of Arch AUR)
* Mon Jun 22 2015 avvissu@yandex.ru
- Fix build with gcc5 (cclive-0.9.3_gcc5.patch)
- Use AM subdir-objects (cclive-0.9.3_subdir.patch)
* Mon Jan 12 2015 avvissu@yandex.ru
- Fix build error on openSUSE > 13.2 (cclive-0.9.3_iostream.patch)
* Tue Oct 28 2014 avvissu@yandex.ru
- Update to 0.9.3 (unstable):
  * improved option parsing
  * improved input parsing
  * libquvi 0.9+ support
  * licensing changes
- Spec file cleanup
* Sun Oct 26 2014 avvissu@yandex.ru
- Update to 0.7.16:
  * fix network options work only partially or not at all
- Change in 0.7.15:
  * add --timestamp: Try to preserve modification time
- Change in 0.7.14:
  * --filename-format: Print a notice of deprecated %%h sequence
  * fix warning message for "--query-formats deprecated"
- Change in 0.7.13:
  * add --print-config
  * add short-option for --verbose-libcurl
  * fix skip transfer with USR1, do not retry transfer
- Change in 0.7.12:
  * add quvi compatibility layer
  * add short-option -h
  * add short-option -v
  * deprecate --format, add --stream
  * deprecate --query-formats, add --print-streams
  * fix do not ignore I/O errors during file transfer
- Change in 0.7.11 (no user-visible changes)
- Change in 0.7.10:
  * manual: Revise descriptions for option sections
  * fix return non-zero exit status if failure
* Sun Jul  8 2012 dnh@opensuse.org
- update to 0.7.9
* Tue Nov 29 2011 reddwarf@opensuse.org
- update to 0.7.8
* Sun Mar 13 2011 pascal.bleser@opensuse.org
- update to 0.7.3 (no user-visible changes)
* Sat Feb 12 2011 pascal.bleser@opensuse.org
- update to 0.7.2:
  * SIGUSR1 handling was added
  * a progress meter was added
  * a Window resizing issue with the progressbar was addressed
* Tue May 18 2010 pascal@links2linux.de
- update to 0.6.3:
  * update to use libquvi's quvi_next_supported_website function
  * add AM_SILENT_RULES(yes)
* Wed Mar 31 2010 pascal@links2linux.de
- update to 0.6.2:
  * fixes an issue with the format option preventing the use of the "best" ID
* Sat Feb 13 2010 pascal@links2linux.de
- update to 0.6.1:
  * fixes a "missing separator" bug and replaces hardcoded format
    ID values with libquvi provided values
* Fri Dec 18 2009 pascal.bleser@opensuse.org
- update to 0.5.7:
  * adds additional regular expression support to --substitute
  * fixes a few bugs
* Thu Oct 15 2009 pascal.bleser@opensuse.org
- update to 0.5.3:
  * addresses some of the libiconv issues found on some platforms
  * improves the video page fetching by dropping the use of the tmpfile function altogether
* Wed Sep 30 2009 pascal.bleser@opensuse.org
- update to 0.5.2:
  * fixes a number of issues with some of the supported Web sites
* Tue Sep 15 2009 pascal.bleser@opensuse.org
- update to 0.5.1:
  * fixes Break Website support
  * addresses a Google video title parsing issue
  * the resumed transfers are no longer treated as errors when the server returns HTTP/206
* Sat Aug 29 2009 pascal.bleser@opensuse.org
- update to 0.5.0:
  * replaces the Perl dependency with iconv and PCRE, reducing memory usage with video titles significantly
  * adds support for the remaining Web sites from clive
  * adds a few new options
  * parses video titles by default
* Thu Jul 30 2009 pascal.bleser@opensuse.org
- update to 0.4.6:
  * this release adds support for a few new Web sites
  * adds a --stream-pass option
  * fixes Unicode support and dailymotion support
  * ports a number of other changes from clive
* Tue Jul  7 2009 pascal.bleser@opensuse.org
- update to 0.4.5:
  * adds tests
  * fixes Google mp4 support
  * implements return codes
* Mon Jun 22 2009 pascal.bleser@opensuse.org
- update to 0.4.4:
  * Vimeo support
* Sun Jun 14 2009 pascal.bleser@opensuse.org
- update to 0.4.3:
  * fixes a number of bugs
  * adds new format options
* Sat May  9 2009 pascal.bleser@opensuse.org
- update to 0.4.2
* Fri Apr 17 2009 pascal.bleser@opensuse.org
- update to 0.3.2:
  * adds the requested connect timeout options
* Sun Apr  5 2009 pascal.bleser@opensuse.org
- update to 0.3.1:
  * adds YouTube HD support
  * adds content-type parsing
  * cleans up the manual page
* Fri Mar 27 2009 pascal.bleser@opensuse.org
- update to 0.3.0
* Wed Mar 18 2009 pascal.bleser@opensuse.org
- update to 0.2.5:
  * fixes GoogleVideo support
  * ports LastFm-Youtube support from clive
* Tue Mar 10 2009 guru@unixtech.be
- update to 0.2.4:
  * adds new title and streaming features
* Sat Feb 21 2009 guru@unixtech.be
- update to 0.2.3:
  * fixes a file naming issue which caused files to be named only as numeric
    suffices
  * an additional option has been added
* Sun Feb 15 2009 guru@unixtech.be
- update to 0.2.2:
  * minor bugfixes
  * a few new features
* Tue Feb 10 2009 guru@unixtech.be
- update to 0.2.0:
  * fixes Sevenload support
  * adds support for Dailymotion
  * changes the output file name template
  * fixes some memory leaks
* Sun Feb  1 2009 guru@unixtech.be
- new package
